@@ -150,7 +150,7 @@ class Databricks(object):
 
         try:
             response = requests.get(uri, headers = self.__header, json = body)
-            runUri = json.loads(response)["execution_duration"]
+            runUri = json.loads(response.content)["execution_duration"]
             return runUri
         except Exception as ex:
             raise ex
@@ -170,7 +170,7 @@ class Databricks(object):
 
         try:
             response = requests.get(uri, headers = self.__header, json = body)
-            notebookDetails = json.loads(response)
+            notebookDetails = json.loads(response.content)
             return notebookDetails
         except Exception as ex:
             raise ex
